@@ -1,6 +1,6 @@
 package DBIx::Class::InflateColumn::ClassTypeEnum;
 # ABSTRACT: Inflate enum-like columns to your Class::Type::Enum classes
-$DBIx::Class::InflateColumn::ClassTypeEnum::VERSION = '0.005';
+$DBIx::Class::InflateColumn::ClassTypeEnum::VERSION = '0.006';
 
 use warnings;
 use strict;
@@ -28,7 +28,7 @@ method register_column ($column, $info) {
       $column => {
         inflate => fun ($ord = undef) {
           return unless defined $ord;
-          $class->inflate($ord);
+          $class->inflate_ordinal($ord);
         },
         deflate => fun ($enum = undef) {
           return unless defined $enum;
@@ -43,7 +43,7 @@ method register_column ($column, $info) {
       $column => {
         inflate => fun ($val = undef) {
           return unless defined $val;
-          $class->inflate_value($val);
+          $class->inflate_symbol($val);
         },
         deflate => fun ($enum = undef) {
           return unless defined $enum;
@@ -69,7 +69,7 @@ DBIx::Class::InflateColumn::ClassTypeEnum - Inflate enum-like columns to your Cl
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,7 @@ Meredith Howard <mhoward@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Meredith Howard.
+This software is copyright (c) 2016 by Meredith Howard.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
